@@ -59,8 +59,10 @@ __all__ = (
     "ProjectTypeDef",
     "RegistryCredentialTypeDef",
     "ReportExportConfigTypeDef",
+    "ReportGroupTrendStatsTypeDef",
     "ReportGroupTypeDef",
     "ReportTypeDef",
+    "ReportWithRawDataTypeDef",
     "ResolvedArtifactTypeDef",
     "ResponseMetadata",
     "S3LogsConfigTypeDef",
@@ -87,6 +89,7 @@ __all__ = (
     "DeleteSourceCredentialsOutputTypeDef",
     "DescribeCodeCoveragesOutputTypeDef",
     "DescribeTestCasesOutputTypeDef",
+    "GetReportGroupTrendOutputTypeDef",
     "GetResourcePolicyOutputTypeDef",
     "ImportSourceCredentialsOutputTypeDef",
     "ListBuildBatchesForProjectOutputTypeDef",
@@ -621,6 +624,10 @@ ReportExportConfigTypeDef = TypedDict(
     total=False,
 )
 
+ReportGroupTrendStatsTypeDef = TypedDict(
+    "ReportGroupTrendStatsTypeDef", {"average": str, "max": str, "min": str}, total=False
+)
+
 ReportGroupTypeDef = TypedDict(
     "ReportGroupTypeDef",
     {
@@ -655,6 +662,10 @@ ReportTypeDef = TypedDict(
     total=False,
 )
 
+ReportWithRawDataTypeDef = TypedDict(
+    "ReportWithRawDataTypeDef", {"reportArn": str, "data": str}, total=False
+)
+
 ResolvedArtifactTypeDef = TypedDict(
     "ResolvedArtifactTypeDef",
     {"type": Literal["CODEPIPELINE", "S3", "NO_ARTIFACTS"], "location": str, "identifier": str},
@@ -895,6 +906,16 @@ DescribeTestCasesOutputTypeDef = TypedDict(
     total=False,
 )
 
+GetReportGroupTrendOutputTypeDef = TypedDict(
+    "GetReportGroupTrendOutputTypeDef",
+    {
+        "stats": "ReportGroupTrendStatsTypeDef",
+        "rawData": List["ReportWithRawDataTypeDef"],
+        "ResponseMetadata": "ResponseMetadata",
+    },
+    total=False,
+)
+
 GetResourcePolicyOutputTypeDef = TypedDict(
     "GetResourcePolicyOutputTypeDef",
     {"policy": str, "ResponseMetadata": "ResponseMetadata"},
